==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/wsdl/model/TBindingOperation.java <==

package org.somda.sdc.dpws.wsdl.model;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for tBindingOperation complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="tBindingOperation"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schemas.xmlsoap.org/wsdl/}tExtensibleDocumented"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="input" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationMessage" minOccurs="0"/&gt;
 *         &lt;element name="output" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationMessage" minOccurs="0"/&gt;
 *         &lt;element name="fault" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationFault" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tBindingOperation", namespace = "http://schemas.xmlsoap.org/wsdl/", propOrder = {
    "input",
    "output",
    "fault"
})
public class TBindingOperation
    extends TExtensibleDocumented
    implements ToString2
{

    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected TBindingOperationMessage input;
    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected TBindingOperationMessage output;
    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected List<TBindingOperationFault> fault;
    @XmlAttribute(name = "name", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String name;

    /**
     * Ruft den Wert der input-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public TBindingOperationMessage getInput() {
        return input;
    }

    /**
     * Legt den Wert der input-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public void setInput(TBindingOperationMessage value) {
        this.input = value;
    }

    /**
     * Ruft den Wert der output-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public TBindingOperationMessage getOutput() {
        return output;
    }

    /**
     * Legt den Wert der output-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public void setOutput(TBindingOperationMessage value) {
        this.output = value;
    }

    /**
     * Gets the value of the fault property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the fault property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFault().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TBindingOperationFault }
     * 
     * 
     */
    public List<TBindingOperationFault> getFault() {
        if (fault == null) {
            fault = new ArrayList<TBindingOperationFault>();
        }
        return this.fault;
    }

    /**
     * Ruft den Wert der name-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Legt den Wert der name-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public void setFault(List<TBindingOperationFault> value) {
        this.fault = null;
        if (value!= null) {
            List<TBindingOperationFault> draftl = this.getFault();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(object)) {
            return false;
        }
        final TBindingOperation that = ((TBindingOperation) object);
        {
            TBindingOperationMessage leftInput;
            leftInput = this.getInput();
            TBindingOperationMessage rightInput;
            rightInput = that.getInput();
            if (this.input!= null) {
                if (that.input!= null) {
                    if (!leftInput.equals(rightInput)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.input!= null) {
                    return false;
                }
            }
        }
        {
            TBindingOperationMessage leftOutput;
            leftOutput = this.getOutput();
            TBindingOperationMessage rightOutput;
            rightOutput = that.getOutput();
            if (this.output!= null) {
                if (that.output!= null) {
                    if (!leftOutput.equals(rightOutput)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.output!= null) {
                    return false;
                }
            }
        }
        {
            List<TBindingOperationFault> leftFault;
            leftFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            List<TBindingOperationFault> rightFault;
            rightFault = (((that.fault!= null)&&(!that.fault.isEmpty()))?that.getFault():null);
            if ((this.fault!= null)&&(!this.fault.isEmpty())) {
                if ((that.fault!= null)&&(!that.fault.isEmpty())) {
                    if (!leftFault.equals(rightFault)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.fault!= null)&&(!that.fault.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftName;
            leftName = this.getName();
            String rightName;
            rightName = that.getName();
            if (this.name!= null) {
                if (that.name!= null) {
                    if (!leftName.equals(rightName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.name!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        currentHashCode = ((currentHashCode* 31)+ super.hashCode());
        {
            currentHashCode = (currentHashCode* 31);
            TBindingOperationMessage theInput;
            theInput = this.getInput();
            if (this.input!= null) {
                currentHashCode += theInput.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            TBindingOperationMessage theOutput;
            theOutput = this.getOutput();
            if (this.output!= null) {
                currentHashCode += theOutput.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<TBindingOperationFault> theFault;
            theFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            if ((this.fault!= null)&&(!this.fault.isEmpty())) {
                currentHashCode += theFault.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theName;
            theName = this.getName();
            if (this.name!= null) {
                currentHashCode += theName.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            TBindingOperationMessage theInput;
            theInput = this.getInput();
            strategy.appendField(locator, this, "input", buffer, theInput, (this.input!= null));
        }
        {
            TBindingOperationMessage theOutput;
            theOutput = this.getOutput();
            strategy.appendField(locator, this, "output", buffer, theOutput, (this.output!= null));
        }
        {
            List<TBindingOperationFault> theFault;
            theFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            strategy.appendField(locator, this, "fault", buffer, theFault, ((this.fault!= null)&&(!this.fault.isEmpty())));
        }
        {
            String theName;
            theName = this.getName();
            strategy.appendField(locator, this, "name", buffer, theName, (this.name!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/wsdl/model/TBindingOperation.java <==

package org.somda.sdc.dpws.wsdl.model;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for tBindingOperation complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="tBindingOperation"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schemas.xmlsoap.org/wsdl/}tExtensibleDocumented"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="input" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationMessage" minOccurs="0"/&gt;
 *         &lt;element name="output" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationMessage" minOccurs="0"/&gt;
 *         &lt;element name="fault" type="{http://schemas.xmlsoap.org/wsdl/}tBindingOperationFault" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tBindingOperation", namespace = "http://schemas.xmlsoap.org/wsdl/", propOrder = {
    "input",
    "output",
    "fault"
})
public class TBindingOperation
    extends TExtensibleDocumented
    implements ToString2
{

    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected TBindingOperationMessage input;
    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected TBindingOperationMessage output;
    @XmlElement(namespace = "http://schemas.xmlsoap.org/wsdl/")
    protected List<TBindingOperationFault> fault;
    @XmlAttribute(name = "name", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String name;

    /**
     * Gets the value of the input property.
     * 
     * @return
     *     possible object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public TBindingOperationMessage getInput() {
        return input;
    }

    /**
     * Sets the value of the input property.
     * 
     * @param value
     *     allowed object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public void setInput(TBindingOperationMessage value) {
        this.input = value;
    }

    /**
     * Gets the value of the output property.
     * 
     * @return
     *     possible object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public TBindingOperationMessage getOutput() {
        return output;
    }

    /**
     * Sets the value of the output property.
     * 
     * @param value
     *     allowed object is
     *     {@link TBindingOperationMessage }
     *     
     */
    public void setOutput(TBindingOperationMessage value) {
        this.output = value;
    }

    /**
     * Gets the value of the fault property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the fault property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFault().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TBindingOperationFault }
     * 
     * 
     */
    public List<TBindingOperationFault> getFault() {
        if (fault == null) {
            fault = new ArrayList<TBindingOperationFault>();
        }
        return this.fault;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public void setFault(List<TBindingOperationFault> value) {
        this.fault = null;
        if (value!= null) {
            List<TBindingOperationFault> draftl = this.getFault();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(object)) {
            return false;
        }
        final TBindingOperation that = ((TBindingOperation) object);
        {
            TBindingOperationMessage leftInput;
            leftInput = this.getInput();
            TBindingOperationMessage rightInput;
            rightInput = that.getInput();
            if (this.input!= null) {
                if (that.input!= null) {
                    if (!leftInput.equals(rightInput)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.input!= null) {
                    return false;
                }
            }
        }
        {
            TBindingOperationMessage leftOutput;
            leftOutput = this.getOutput();
            TBindingOperationMessage rightOutput;
            rightOutput = that.getOutput();
            if (this.output!= null) {
                if (that.output!= null) {
                    if (!leftOutput.equals(rightOutput)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.output!= null) {
                    return false;
                }
            }
        }
        {
            List<TBindingOperationFault> leftFault;
            leftFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            List<TBindingOperationFault> rightFault;
            rightFault = (((that.fault!= null)&&(!that.fault.isEmpty()))?that.getFault():null);
            if ((this.fault!= null)&&(!this.fault.isEmpty())) {
                if ((that.fault!= null)&&(!that.fault.isEmpty())) {
                    if (!leftFault.equals(rightFault)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.fault!= null)&&(!that.fault.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftName;
            leftName = this.getName();
            String rightName;
            rightName = that.getName();
            if (this.name!= null) {
                if (that.name!= null) {
                    if (!leftName.equals(rightName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.name!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        currentHashCode = ((currentHashCode* 31)+ super.hashCode());
        {
            currentHashCode = (currentHashCode* 31);
            TBindingOperationMessage theInput;
            theInput = this.getInput();
            if (this.input!= null) {
                currentHashCode += theInput.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            TBindingOperationMessage theOutput;
            theOutput = this.getOutput();
            if (this.output!= null) {
                currentHashCode += theOutput.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<TBindingOperationFault> theFault;
            theFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            if ((this.fault!= null)&&(!this.fault.isEmpty())) {
                currentHashCode += theFault.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theName;
            theName = this.getName();
            if (this.name!= null) {
                currentHashCode += theName.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            TBindingOperationMessage theInput;
            theInput = this.getInput();
            strategy.appendField(locator, this, "input", buffer, theInput, (this.input!= null));
        }
        {
            TBindingOperationMessage theOutput;
            theOutput = this.getOutput();
            strategy.appendField(locator, this, "output", buffer, theOutput, (this.output!= null));
        }
        {
            List<TBindingOperationFault> theFault;
            theFault = (((this.fault!= null)&&(!this.fault.isEmpty()))?this.getFault():null);
            strategy.appendField(locator, this, "fault", buffer, theFault, ((this.fault!= null)&&(!this.fault.isEmpty())));
        }
        {
            String theName;
            theName = this.getName();
            strategy.appendField(locator, this, "name", buffer, theName, (this.name!= null));
        }
        return buffer;
    }

}
